diff -r ab7e3294572e src/SciTEBase.h
--- a/src/SciTEBase.h	Sun Jul 29 17:09:36 2012 +1000
+++ b/src/SciTEBase.h	Thu Aug 02 22:23:15 2012 +1000
@@ -398,6 +398,7 @@
 	int characterSet;
 	SString language;
 	int lexLanguage;
+	std::vector<char> subStyleBases;
 	int lexLPeg;
 	StringList apis;
 	SString apisFileNames;
diff -r ab7e3294572e src/SciTEProps.cxx
--- a/src/SciTEProps.cxx	Sun Jul 29 17:09:36 2012 +1000
+++ b/src/SciTEProps.cxx	Thu Aug 02 22:23:15 2012 +1000
@@ -808,6 +808,43 @@
 		wEditor.CallString(SCI_SETKEYWORDS, wl, kw.c_str());
 	}
 
+	subStyleBases.clear();
+	int lenSSB = wEditor.CallString(SCI_GETSUBSTYLEBASES, 0, NULL);
+	if (lenSSB) {
+		wEditor.Call(SCI_FREESUBSTYLES);
+
+		subStyleBases.resize(lenSSB+1);
+		wEditor.CallString(SCI_GETSUBSTYLEBASES, 0, &subStyleBases[0]);
+		subStyleBases.resize(lenSSB);	// Remove NUL
+
+		for (int baseStyle=0;baseStyle<lenSSB;baseStyle++) {
+			//substyles.cpp.11=2
+			SString ssSubStylesKey = "substyles.";
+			ssSubStylesKey += language;
+			ssSubStylesKey += ".";
+			ssSubStylesKey += SString(subStyleBases[baseStyle]);
+			SString ssNumber = props.GetNewExpand(ssSubStylesKey.c_str());
+			int subStyleIdentifiers = ssNumber.value();
+
+			int subStyleIdentifiersStart = 0;
+			if (subStyleIdentifiers) {
+				subStyleIdentifiersStart = wEditor.Call(SCI_ALLOCATESUBSTYLES, subStyleBases[baseStyle], subStyleIdentifiers);
+				if (subStyleIdentifiersStart < 0)
+					subStyleIdentifiers = 0;
+			}
+			for (int subStyle=0; subStyle<subStyleIdentifiers; subStyle++) {
+				// substylewords.11.1.$(file.patterns.cpp)=CharacterSet LexAccessor SString WordList
+				SString ssWordsKey = "substylewords.";
+				ssWordsKey += SString(subStyleBases[baseStyle]);
+				ssWordsKey += ".";
+				ssWordsKey += SString(subStyle+1);
+				ssWordsKey += ".";
+				SString ssWords = props.GetNewExpand(ssWordsKey.c_str(), fileNameForExtension.c_str());
+				wEditor.CallString(SCI_SETIDENTIFIERS, subStyleIdentifiersStart + subStyle, ssWords.c_str());
+			}
+		}
+	}
+
 	FilePath homepath = GetSciteDefaultHome();
 	props.Set("SciteDefaultHome", homepath.AsUTF8().c_str());
 	homepath = GetSciteUserHome();
@@ -1422,6 +1459,20 @@
 		SetStyleBlock(wEditor, "error", diagnosticStyleStart, diagnosticStyleEnd);
 	}
 
+	int diffToSecondary = static_cast<int>(wEditor.Call(SCI_DISTANCETOSECONDARYSTYLES));
+	for (unsigned int baseStyle=0; baseStyle<subStyleBases.size(); baseStyle++) {
+		int subStylesStart = wEditor.Call(SCI_GETSUBSTYLESSTART, subStyleBases[baseStyle]);
+		int subStylesLength = wEditor.Call(SCI_GETSUBSTYLESLENGTH, subStyleBases[baseStyle]);
+		for (int subStyle=0; subStyle<subStylesLength; subStyle++) {
+			for (int active=0; active<(diffToSecondary?2:1); active++) {
+				int activity = active * diffToSecondary;
+				sprintf(key, "style.%s.%0d.%0d", languageName, subStyleBases[baseStyle] + activity, subStyle+1);
+				sval = props.GetNewExpand(key);
+				SetOneStyle(wEditor, subStylesStart + subStyle + activity, sval.c_str());
+			}
+		}
+	}
+
 	// Turn grey while loading
 	if (CurrentBuffer()->lifeState == Buffer::reading)
 		wEditor.Call(SCI_STYLESETBACK, STYLE_DEFAULT, 0xEEEEEE);
